@@ -1,6 +1,9 @@
 options(lidR.progress = FALSE)
 options(rgl.useNULL = TRUE)
-rgdal::set_thin_PROJ6_warnings(TRUE)
+
+cat("Tests using raster:", getOption("lidR.raster.default"), "\n")
+cat("Tests using future:", lidR:::engine_use_future(), "\n")
+cat("Tests using OpenMP thread:", get_lidr_threads(), "\n")
 #Sys.setenv(NOT_CRAN = "false")
 
 megaplot_laz_path <- system.file("extdata", "Megaplot.laz", package="lidR")
@@ -30,3 +33,5 @@ mixedconifer_ctg <- readLAScatalog(mixedconifer_las_path)
 topography_ctg <- readLAScatalog(topography_las_path)
 example_ctg <- readLAScatalog(example_las_path)
 random_2files_250points <- lidR:::catalog_generator(2, 250) # 180 ms
+
+chunk = lidR:::engine_chunks(random_2files_250points)[[1]]
